==> haskell-configurator-0.3.0.0-205-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-configurator.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 configurator
version:              0.3.0.0
visibility:           public
id:                   configurator-0.3.0.0-KfqlHOKvgmTcdmXdm9DHm
key:                  configurator-0.3.0.0-KfqlHOKvgmTcdmXdm9DHm
license:              BSD-3-Clause
copyright:
    Copyright 2011 MailRank, Inc.
    Copyright 2011-2014 Bryan O'\''Sullivan

maintainer:           Bryan O'\''Sullivan <bos@serpentine.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             http://github.com/bos/configurator
synopsis:             Configuration management
description:
    A configuration management library for programs and daemons.

    Features include:

    * Automatic, dynamic reloading in response to modifications to
    configuration files.

    * A simple, but flexible, configuration language, supporting several
    of the most commonly needed types of data, along with
    interpolation of strings from the configuration or the system
    environment (e.g. @$(HOME)@).

    * Subscription-based notification of changes to configuration
    properties.

    * An @import@ directive allows the configuration of a complex
    application to be split across several smaller files, or common
    configuration data to be shared across several applications.

    For details of the configuration file format, see
    <http://hackage.haskell.org/packages/archive/configurator/latest/doc/html/Data-Configurator.html>.

category:             Configuration, Data
abi:                  503c3c9f0e1bb6d846896880a903a832
exposed:              True
exposed-modules:      Data.Configurator Data.Configurator.Types
hidden-modules:
    Data.Configurator.Instances Data.Configurator.Parser
    Data.Configurator.Types.Internal

import-dirs:          /usr/lib/ghc-8.10.4/site-local/configurator-0.3.0.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/configurator-0.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-configurator
hs-libraries:         HSconfigurator-0.3.0.0-KfqlHOKvgmTcdmXdm9DHm
depends:
    attoparsec-0.14.1-Dlm5EB3n5xmG4Iku2w73OX base-4.14.1.0
    bytestring-0.10.12.0 directory-1.3.6.0
    hashable-1.3.1.0-4EsGp1K7uOu2cACWuCidz3 text-1.2.4.1
    unix-compat-0.5.3-E98n0JyMac7Bz478oqWJHX
    unordered-containers-0.2.13.0-4AoMTstniRpGNa4LW5BINH

haddock-interfaces:
    /usr/share/doc/haskell-configurator/html/configurator.haddock

haddock-html:         /usr/share/doc/haskell-configurator/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-configurator-0.3.0.0-210-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-configurator.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 configurator
version:              0.3.0.0
visibility:           public
id:                   configurator-0.3.0.0-6QXSbATvl9L3tcPq6sD6yx
key:                  configurator-0.3.0.0-6QXSbATvl9L3tcPq6sD6yx
license:              BSD-3-Clause
copyright:
    Copyright 2011 MailRank, Inc.
    Copyright 2011-2014 Bryan O'\''Sullivan

maintainer:           Bryan O'\''Sullivan <bos@serpentine.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             http://github.com/bos/configurator
synopsis:             Configuration management
description:
    A configuration management library for programs and daemons.

    Features include:

    * Automatic, dynamic reloading in response to modifications to
    configuration files.

    * A simple, but flexible, configuration language, supporting several
    of the most commonly needed types of data, along with
    interpolation of strings from the configuration or the system
    environment (e.g. @$(HOME)@).

    * Subscription-based notification of changes to configuration
    properties.

    * An @import@ directive allows the configuration of a complex
    application to be split across several smaller files, or common
    configuration data to be shared across several applications.

    For details of the configuration file format, see
    <http://hackage.haskell.org/packages/archive/configurator/latest/doc/html/Data-Configurator.html>.

category:             Configuration, Data
abi:                  ce7c21a6bc3d18e9186b37234fd9d724
exposed:              True
exposed-modules:      Data.Configurator Data.Configurator.Types
hidden-modules:
    Data.Configurator.Instances Data.Configurator.Parser
    Data.Configurator.Types.Internal

import-dirs:          /usr/lib/ghc-8.10.4/site-local/configurator-0.3.0.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/configurator-0.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-configurator
hs-libraries:         HSconfigurator-0.3.0.0-6QXSbATvl9L3tcPq6sD6yx
depends:
    attoparsec-0.14.1-C6wGreXaJC9Hw3F0wMqT0I base-4.14.1.0
    bytestring-0.10.12.0 directory-1.3.6.0
    hashable-1.3.2.0-5x51STP8vZMKBx9J0CoY3R text-1.2.4.1
    unix-compat-0.5.3-E98n0JyMac7Bz478oqWJHX
    unordered-containers-0.2.14.0-HPNAhY9eekUIwMlQFAvZlw

haddock-interfaces:
    /usr/share/doc/haskell-configurator/html/configurator.haddock

haddock-html:         /usr/share/doc/haskell-configurator/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
